# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class DatasetSetup(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "outputs",
            "metadata",
            "preprocess",
            "inputs",
            "custom_loss_names",
            "prediction_types",
            "visualizers",
        }
        
        class properties:
        
            @staticmethod
            def preprocess() -> typing.Type['DatasetPreprocess']:
                return DatasetPreprocess
            
            
            class inputs(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['DatasetInputInstance']:
                        return DatasetInputInstance
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['DatasetInputInstance'], typing.List['DatasetInputInstance']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'inputs':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'DatasetInputInstance':
                    return super().__getitem__(i)
            
            
            class metadata(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['DatasetMetadataInstance']:
                        return DatasetMetadataInstance
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['DatasetMetadataInstance'], typing.List['DatasetMetadataInstance']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'metadata':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'DatasetMetadataInstance':
                    return super().__getitem__(i)
            
            
            class outputs(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['DatasetOutputInstance']:
                        return DatasetOutputInstance
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['DatasetOutputInstance'], typing.List['DatasetOutputInstance']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'outputs':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'DatasetOutputInstance':
                    return super().__getitem__(i)
            
            
            class visualizers(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['VisualizerInstance']:
                        return VisualizerInstance
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['VisualizerInstance'], typing.List['VisualizerInstance']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'visualizers':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'VisualizerInstance':
                    return super().__getitem__(i)
            
            
            class prediction_types(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['PredictionTypeInstance']:
                        return PredictionTypeInstance
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['PredictionTypeInstance'], typing.List['PredictionTypeInstance']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'prediction_types':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'PredictionTypeInstance':
                    return super().__getitem__(i)
            
            
            class custom_loss_names(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'custom_loss_names':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "preprocess": preprocess,
                "inputs": inputs,
                "metadata": metadata,
                "outputs": outputs,
                "visualizers": visualizers,
                "prediction_types": prediction_types,
                "custom_loss_names": custom_loss_names,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    outputs: MetaOapg.properties.outputs
    metadata: MetaOapg.properties.metadata
    preprocess: 'DatasetPreprocess'
    inputs: MetaOapg.properties.inputs
    custom_loss_names: MetaOapg.properties.custom_loss_names
    prediction_types: MetaOapg.properties.prediction_types
    visualizers: MetaOapg.properties.visualizers
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["outputs"]) -> MetaOapg.properties.outputs: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["preprocess"]) -> 'DatasetPreprocess': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["inputs"]) -> MetaOapg.properties.inputs: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_loss_names"]) -> MetaOapg.properties.custom_loss_names: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["prediction_types"]) -> MetaOapg.properties.prediction_types: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["visualizers"]) -> MetaOapg.properties.visualizers: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["outputs"], typing_extensions.Literal["metadata"], typing_extensions.Literal["preprocess"], typing_extensions.Literal["inputs"], typing_extensions.Literal["custom_loss_names"], typing_extensions.Literal["prediction_types"], typing_extensions.Literal["visualizers"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["outputs"]) -> MetaOapg.properties.outputs: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["preprocess"]) -> 'DatasetPreprocess': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["inputs"]) -> MetaOapg.properties.inputs: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_loss_names"]) -> MetaOapg.properties.custom_loss_names: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["prediction_types"]) -> MetaOapg.properties.prediction_types: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["visualizers"]) -> MetaOapg.properties.visualizers: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["outputs"], typing_extensions.Literal["metadata"], typing_extensions.Literal["preprocess"], typing_extensions.Literal["inputs"], typing_extensions.Literal["custom_loss_names"], typing_extensions.Literal["prediction_types"], typing_extensions.Literal["visualizers"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        outputs: typing.Union[MetaOapg.properties.outputs, list, tuple, ],
        metadata: typing.Union[MetaOapg.properties.metadata, list, tuple, ],
        preprocess: 'DatasetPreprocess',
        inputs: typing.Union[MetaOapg.properties.inputs, list, tuple, ],
        custom_loss_names: typing.Union[MetaOapg.properties.custom_loss_names, list, tuple, ],
        prediction_types: typing.Union[MetaOapg.properties.prediction_types, list, tuple, ],
        visualizers: typing.Union[MetaOapg.properties.visualizers, list, tuple, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'DatasetSetup':
        return super().__new__(
            cls,
            *args,
            outputs=outputs,
            metadata=metadata,
            preprocess=preprocess,
            inputs=inputs,
            custom_loss_names=custom_loss_names,
            prediction_types=prediction_types,
            visualizers=visualizers,
            _configuration=_configuration,
        )

from openapi_client.model.dataset_input_instance import DatasetInputInstance
from openapi_client.model.dataset_metadata_instance import DatasetMetadataInstance
from openapi_client.model.dataset_output_instance import DatasetOutputInstance
from openapi_client.model.dataset_preprocess import DatasetPreprocess
from openapi_client.model.prediction_type_instance import PredictionTypeInstance
from openapi_client.model.visualizer_instance import VisualizerInstance



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class GetStatisticsResponse(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "models",
            "projects",
            "tests",
            "activeUsers",
            "networks",
            "openIssues",
        }
        
        class properties:
            activeUsers = schemas.Float64Schema
            openIssues = schemas.Float64Schema
            tests = schemas.Float64Schema
            projects = schemas.Float64Schema
            networks = schemas.Float64Schema
            models = schemas.Float64Schema
            __annotations__ = {
                "activeUsers": activeUsers,
                "openIssues": openIssues,
                "tests": tests,
                "projects": projects,
                "networks": networks,
                "models": models,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    models: MetaOapg.properties.models
    projects: MetaOapg.properties.projects
    tests: MetaOapg.properties.tests
    activeUsers: MetaOapg.properties.activeUsers
    networks: MetaOapg.properties.networks
    openIssues: MetaOapg.properties.openIssues
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["models"]) -> MetaOapg.properties.models: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["projects"]) -> MetaOapg.properties.projects: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tests"]) -> MetaOapg.properties.tests: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["activeUsers"]) -> MetaOapg.properties.activeUsers: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["networks"]) -> MetaOapg.properties.networks: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["openIssues"]) -> MetaOapg.properties.openIssues: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["models"], typing_extensions.Literal["projects"], typing_extensions.Literal["tests"], typing_extensions.Literal["activeUsers"], typing_extensions.Literal["networks"], typing_extensions.Literal["openIssues"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["models"]) -> MetaOapg.properties.models: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["projects"]) -> MetaOapg.properties.projects: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tests"]) -> MetaOapg.properties.tests: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["activeUsers"]) -> MetaOapg.properties.activeUsers: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["networks"]) -> MetaOapg.properties.networks: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["openIssues"]) -> MetaOapg.properties.openIssues: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["models"], typing_extensions.Literal["projects"], typing_extensions.Literal["tests"], typing_extensions.Literal["activeUsers"], typing_extensions.Literal["networks"], typing_extensions.Literal["openIssues"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        models: typing.Union[MetaOapg.properties.models, decimal.Decimal, int, float, ],
        projects: typing.Union[MetaOapg.properties.projects, decimal.Decimal, int, float, ],
        tests: typing.Union[MetaOapg.properties.tests, decimal.Decimal, int, float, ],
        activeUsers: typing.Union[MetaOapg.properties.activeUsers, decimal.Decimal, int, float, ],
        networks: typing.Union[MetaOapg.properties.networks, decimal.Decimal, int, float, ],
        openIssues: typing.Union[MetaOapg.properties.openIssues, decimal.Decimal, int, float, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'GetStatisticsResponse':
        return super().__new__(
            cls,
            *args,
            models=models,
            projects=projects,
            tests=tests,
            activeUsers=activeUsers,
            networks=networks,
            openIssues=openIssues,
            _configuration=_configuration,
        )



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class LossMessageParams(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "module",
            "message",
            "loss_name",
            "node_id",
        }
        
        class properties:
            message = schemas.StrSchema
            loss_name = schemas.StrSchema
            node_id = schemas.StrSchema
        
            @staticmethod
            def module() -> typing.Type['Module']:
                return Module
            message_code = schemas.StrSchema
            __annotations__ = {
                "message": message,
                "loss_name": loss_name,
                "node_id": node_id,
                "module": module,
                "message_code": message_code,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    module: 'Module'
    message: MetaOapg.properties.message
    loss_name: MetaOapg.properties.loss_name
    node_id: MetaOapg.properties.node_id
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["module"]) -> 'Module': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["message"]) -> MetaOapg.properties.message: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["loss_name"]) -> MetaOapg.properties.loss_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["node_id"]) -> MetaOapg.properties.node_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["message_code"]) -> MetaOapg.properties.message_code: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["module"], typing_extensions.Literal["message"], typing_extensions.Literal["loss_name"], typing_extensions.Literal["node_id"], typing_extensions.Literal["message_code"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["module"]) -> 'Module': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["message"]) -> MetaOapg.properties.message: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["loss_name"]) -> MetaOapg.properties.loss_name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["node_id"]) -> MetaOapg.properties.node_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["message_code"]) -> typing.Union[MetaOapg.properties.message_code, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["module"], typing_extensions.Literal["message"], typing_extensions.Literal["loss_name"], typing_extensions.Literal["node_id"], typing_extensions.Literal["message_code"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        module: 'Module',
        message: typing.Union[MetaOapg.properties.message, str, ],
        loss_name: typing.Union[MetaOapg.properties.loss_name, str, ],
        node_id: typing.Union[MetaOapg.properties.node_id, str, ],
        message_code: typing.Union[MetaOapg.properties.message_code, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'LossMessageParams':
        return super().__new__(
            cls,
            *args,
            module=module,
            message=message,
            loss_name=loss_name,
            node_id=node_id,
            message_code=message_code,
            _configuration=_configuration,
        )

from openapi_client.model.module import Module



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class TourStepDefinition(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "imageSrc",
            "title",
            "content",
            "target",
        }
        
        class properties:
            target = schemas.StrSchema
            title = schemas.StrSchema
            content = schemas.StrSchema
            imageSrc = schemas.StrSchema
            
            
            class placement(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "right": "RIGHT",
                        "left": "LEFT",
                        "top": "TOP",
                        "bottom": "BOTTOM",
                    }
                
                @schemas.classproperty
                def RIGHT(cls):
                    return cls("right")
                
                @schemas.classproperty
                def LEFT(cls):
                    return cls("left")
                
                @schemas.classproperty
                def TOP(cls):
                    return cls("top")
                
                @schemas.classproperty
                def BOTTOM(cls):
                    return cls("bottom")
            fitToScreen = schemas.BoolSchema
            navigateToHash = schemas.StrSchema
            scrollIntoView = schemas.BoolSchema
            
            
            class currentPage(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "profile": "PROFILE",
                        "process": "PROCESS",
                        "versions": "VERSIONS",
                    }
                
                @schemas.classproperty
                def PROFILE(cls):
                    return cls("profile")
                
                @schemas.classproperty
                def PROCESS(cls):
                    return cls("process")
                
                @schemas.classproperty
                def VERSIONS(cls):
                    return cls("versions")
            __annotations__ = {
                "target": target,
                "title": title,
                "content": content,
                "imageSrc": imageSrc,
                "placement": placement,
                "fitToScreen": fitToScreen,
                "navigateToHash": navigateToHash,
                "scrollIntoView": scrollIntoView,
                "currentPage": currentPage,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    imageSrc: MetaOapg.properties.imageSrc
    title: MetaOapg.properties.title
    content: MetaOapg.properties.content
    target: MetaOapg.properties.target
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["imageSrc"]) -> MetaOapg.properties.imageSrc: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["content"]) -> MetaOapg.properties.content: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["target"]) -> MetaOapg.properties.target: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["placement"]) -> MetaOapg.properties.placement: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fitToScreen"]) -> MetaOapg.properties.fitToScreen: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["navigateToHash"]) -> MetaOapg.properties.navigateToHash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["scrollIntoView"]) -> MetaOapg.properties.scrollIntoView: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currentPage"]) -> MetaOapg.properties.currentPage: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["imageSrc"], typing_extensions.Literal["title"], typing_extensions.Literal["content"], typing_extensions.Literal["target"], typing_extensions.Literal["placement"], typing_extensions.Literal["fitToScreen"], typing_extensions.Literal["navigateToHash"], typing_extensions.Literal["scrollIntoView"], typing_extensions.Literal["currentPage"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["imageSrc"]) -> MetaOapg.properties.imageSrc: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["content"]) -> MetaOapg.properties.content: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["target"]) -> MetaOapg.properties.target: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["placement"]) -> typing.Union[MetaOapg.properties.placement, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fitToScreen"]) -> typing.Union[MetaOapg.properties.fitToScreen, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["navigateToHash"]) -> typing.Union[MetaOapg.properties.navigateToHash, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["scrollIntoView"]) -> typing.Union[MetaOapg.properties.scrollIntoView, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currentPage"]) -> typing.Union[MetaOapg.properties.currentPage, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["imageSrc"], typing_extensions.Literal["title"], typing_extensions.Literal["content"], typing_extensions.Literal["target"], typing_extensions.Literal["placement"], typing_extensions.Literal["fitToScreen"], typing_extensions.Literal["navigateToHash"], typing_extensions.Literal["scrollIntoView"], typing_extensions.Literal["currentPage"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        imageSrc: typing.Union[MetaOapg.properties.imageSrc, str, ],
        title: typing.Union[MetaOapg.properties.title, str, ],
        content: typing.Union[MetaOapg.properties.content, str, ],
        target: typing.Union[MetaOapg.properties.target, str, ],
        placement: typing.Union[MetaOapg.properties.placement, str, schemas.Unset] = schemas.unset,
        fitToScreen: typing.Union[MetaOapg.properties.fitToScreen, bool, schemas.Unset] = schemas.unset,
        navigateToHash: typing.Union[MetaOapg.properties.navigateToHash, str, schemas.Unset] = schemas.unset,
        scrollIntoView: typing.Union[MetaOapg.properties.scrollIntoView, bool, schemas.Unset] = schemas.unset,
        currentPage: typing.Union[MetaOapg.properties.currentPage, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'TourStepDefinition':
        return super().__new__(
            cls,
            *args,
            imageSrc=imageSrc,
            title=title,
            content=content,
            target=target,
            placement=placement,
            fitToScreen=fitToScreen,
            navigateToHash=navigateToHash,
            scrollIntoView=scrollIntoView,
            currentPage=currentPage,
            _configuration=_configuration,
        )



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class BoundingBox(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "confidence",
            "width",
            "x",
            "y",
            "label",
            "height",
        }
        
        class properties:
            x = schemas.Float64Schema
            y = schemas.Float64Schema
            width = schemas.Float64Schema
            height = schemas.Float64Schema
            confidence = schemas.Float64Schema
            label = schemas.StrSchema
            __annotations__ = {
                "x": x,
                "y": y,
                "width": width,
                "height": height,
                "confidence": confidence,
                "label": label,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    confidence: MetaOapg.properties.confidence
    width: MetaOapg.properties.width
    x: MetaOapg.properties.x
    y: MetaOapg.properties.y
    label: MetaOapg.properties.label
    height: MetaOapg.properties.height
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["confidence"]) -> MetaOapg.properties.confidence: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["width"]) -> MetaOapg.properties.width: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["x"]) -> MetaOapg.properties.x: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["y"]) -> MetaOapg.properties.y: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["label"]) -> MetaOapg.properties.label: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["height"]) -> MetaOapg.properties.height: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["confidence"], typing_extensions.Literal["width"], typing_extensions.Literal["x"], typing_extensions.Literal["y"], typing_extensions.Literal["label"], typing_extensions.Literal["height"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["confidence"]) -> MetaOapg.properties.confidence: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["width"]) -> MetaOapg.properties.width: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["x"]) -> MetaOapg.properties.x: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["y"]) -> MetaOapg.properties.y: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["label"]) -> MetaOapg.properties.label: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["height"]) -> MetaOapg.properties.height: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["confidence"], typing_extensions.Literal["width"], typing_extensions.Literal["x"], typing_extensions.Literal["y"], typing_extensions.Literal["label"], typing_extensions.Literal["height"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        confidence: typing.Union[MetaOapg.properties.confidence, decimal.Decimal, int, float, ],
        width: typing.Union[MetaOapg.properties.width, decimal.Decimal, int, float, ],
        x: typing.Union[MetaOapg.properties.x, decimal.Decimal, int, float, ],
        y: typing.Union[MetaOapg.properties.y, decimal.Decimal, int, float, ],
        label: typing.Union[MetaOapg.properties.label, str, ],
        height: typing.Union[MetaOapg.properties.height, decimal.Decimal, int, float, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'BoundingBox':
        return super().__new__(
            cls,
            *args,
            confidence=confidence,
            width=width,
            x=x,
            y=y,
            label=label,
            height=height,
            _configuration=_configuration,
        )



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class CustomMessageData(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "level",
            "params",
        }
        
        class properties:
        
            @staticmethod
            def level() -> typing.Type['MessageLevel']:
                return MessageLevel
        
            @staticmethod
            def params() -> typing.Type['CustomMessageDataParams']:
                return CustomMessageDataParams
            __annotations__ = {
                "level": level,
                "params": params,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    level: 'MessageLevel'
    params: 'CustomMessageDataParams'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["level"]) -> 'MessageLevel': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["params"]) -> 'CustomMessageDataParams': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["level"], typing_extensions.Literal["params"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["level"]) -> 'MessageLevel': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["params"]) -> 'CustomMessageDataParams': ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["level"], typing_extensions.Literal["params"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        level: 'MessageLevel',
        params: 'CustomMessageDataParams',
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'CustomMessageData':
        return super().__new__(
            cls,
            *args,
            level=level,
            params=params,
            _configuration=_configuration,
        )

from openapi_client.model.custom_message_data_params import CustomMessageDataParams
from openapi_client.model.message_level import MessageLevel



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class Demo(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "spaceId",
            "versionId",
            "task",
            "subTitle",
            "datatype",
            "modelId",
            "domain",
            "imageUrl",
            "description",
            "title",
            "projectId",
        }
        
        class properties:
            imageUrl = schemas.StrSchema
            title = schemas.StrSchema
            subTitle = schemas.StrSchema
            description = schemas.StrSchema
            domain = schemas.StrSchema
            datatype = schemas.StrSchema
            task = schemas.StrSchema
            projectId = schemas.StrSchema
            versionId = schemas.StrSchema
            modelId = schemas.StrSchema
            spaceId = schemas.StrSchema
            
            
            class demoStepsGuide(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'demoStepsGuide':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
        
            @staticmethod
            def tours() -> typing.Type['PartialRecordTourPageTourStepDefinitionArray']:
                return PartialRecordTourPageTourStepDefinitionArray
            __annotations__ = {
                "imageUrl": imageUrl,
                "title": title,
                "subTitle": subTitle,
                "description": description,
                "domain": domain,
                "datatype": datatype,
                "task": task,
                "projectId": projectId,
                "versionId": versionId,
                "modelId": modelId,
                "spaceId": spaceId,
                "demoStepsGuide": demoStepsGuide,
                "tours": tours,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    spaceId: MetaOapg.properties.spaceId
    versionId: MetaOapg.properties.versionId
    task: MetaOapg.properties.task
    subTitle: MetaOapg.properties.subTitle
    datatype: MetaOapg.properties.datatype
    modelId: MetaOapg.properties.modelId
    domain: MetaOapg.properties.domain
    imageUrl: MetaOapg.properties.imageUrl
    description: MetaOapg.properties.description
    title: MetaOapg.properties.title
    projectId: MetaOapg.properties.projectId
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["spaceId"]) -> MetaOapg.properties.spaceId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["versionId"]) -> MetaOapg.properties.versionId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["task"]) -> MetaOapg.properties.task: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["subTitle"]) -> MetaOapg.properties.subTitle: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["datatype"]) -> MetaOapg.properties.datatype: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["modelId"]) -> MetaOapg.properties.modelId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["domain"]) -> MetaOapg.properties.domain: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["imageUrl"]) -> MetaOapg.properties.imageUrl: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["projectId"]) -> MetaOapg.properties.projectId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["demoStepsGuide"]) -> MetaOapg.properties.demoStepsGuide: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tours"]) -> 'PartialRecordTourPageTourStepDefinitionArray': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["spaceId"], typing_extensions.Literal["versionId"], typing_extensions.Literal["task"], typing_extensions.Literal["subTitle"], typing_extensions.Literal["datatype"], typing_extensions.Literal["modelId"], typing_extensions.Literal["domain"], typing_extensions.Literal["imageUrl"], typing_extensions.Literal["description"], typing_extensions.Literal["title"], typing_extensions.Literal["projectId"], typing_extensions.Literal["demoStepsGuide"], typing_extensions.Literal["tours"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["spaceId"]) -> MetaOapg.properties.spaceId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["versionId"]) -> MetaOapg.properties.versionId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["task"]) -> MetaOapg.properties.task: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["subTitle"]) -> MetaOapg.properties.subTitle: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["datatype"]) -> MetaOapg.properties.datatype: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["modelId"]) -> MetaOapg.properties.modelId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["domain"]) -> MetaOapg.properties.domain: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["imageUrl"]) -> MetaOapg.properties.imageUrl: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["projectId"]) -> MetaOapg.properties.projectId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["demoStepsGuide"]) -> typing.Union[MetaOapg.properties.demoStepsGuide, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tours"]) -> typing.Union['PartialRecordTourPageTourStepDefinitionArray', schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["spaceId"], typing_extensions.Literal["versionId"], typing_extensions.Literal["task"], typing_extensions.Literal["subTitle"], typing_extensions.Literal["datatype"], typing_extensions.Literal["modelId"], typing_extensions.Literal["domain"], typing_extensions.Literal["imageUrl"], typing_extensions.Literal["description"], typing_extensions.Literal["title"], typing_extensions.Literal["projectId"], typing_extensions.Literal["demoStepsGuide"], typing_extensions.Literal["tours"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        spaceId: typing.Union[MetaOapg.properties.spaceId, str, ],
        versionId: typing.Union[MetaOapg.properties.versionId, str, ],
        task: typing.Union[MetaOapg.properties.task, str, ],
        subTitle: typing.Union[MetaOapg.properties.subTitle, str, ],
        datatype: typing.Union[MetaOapg.properties.datatype, str, ],
        modelId: typing.Union[MetaOapg.properties.modelId, str, ],
        domain: typing.Union[MetaOapg.properties.domain, str, ],
        imageUrl: typing.Union[MetaOapg.properties.imageUrl, str, ],
        description: typing.Union[MetaOapg.properties.description, str, ],
        title: typing.Union[MetaOapg.properties.title, str, ],
        projectId: typing.Union[MetaOapg.properties.projectId, str, ],
        demoStepsGuide: typing.Union[MetaOapg.properties.demoStepsGuide, list, tuple, schemas.Unset] = schemas.unset,
        tours: typing.Union['PartialRecordTourPageTourStepDefinitionArray', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Demo':
        return super().__new__(
            cls,
            *args,
            spaceId=spaceId,
            versionId=versionId,
            task=task,
            subTitle=subTitle,
            datatype=datatype,
            modelId=modelId,
            domain=domain,
            imageUrl=imageUrl,
            description=description,
            title=title,
            projectId=projectId,
            demoStepsGuide=demoStepsGuide,
            tours=tours,
            _configuration=_configuration,
        )

from openapi_client.model.partial_record_tour_page_tour_step_definition_array import PartialRecordTourPageTourStepDefinitionArray



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class ScatterFilter(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "metric",
            "value",
            "operator",
        }
        
        class properties:
            metric = schemas.StrSchema
            value = schemas.StrSchema
        
            @staticmethod
            def operator() -> typing.Type['OperatorEnum']:
                return OperatorEnum
        
            @staticmethod
            def data_state() -> typing.Type['DataStateType']:
                return DataStateType
            __annotations__ = {
                "metric": metric,
                "value": value,
                "operator": operator,
                "data_state": data_state,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    metric: MetaOapg.properties.metric
    value: MetaOapg.properties.value
    operator: 'OperatorEnum'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metric"]) -> MetaOapg.properties.metric: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["operator"]) -> 'OperatorEnum': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data_state"]) -> 'DataStateType': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["metric"], typing_extensions.Literal["value"], typing_extensions.Literal["operator"], typing_extensions.Literal["data_state"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metric"]) -> MetaOapg.properties.metric: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["operator"]) -> 'OperatorEnum': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data_state"]) -> typing.Union['DataStateType', schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["metric"], typing_extensions.Literal["value"], typing_extensions.Literal["operator"], typing_extensions.Literal["data_state"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        metric: typing.Union[MetaOapg.properties.metric, str, ],
        value: typing.Union[MetaOapg.properties.value, str, ],
        operator: 'OperatorEnum',
        data_state: typing.Union['DataStateType', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'ScatterFilter':
        return super().__new__(
            cls,
            *args,
            metric=metric,
            value=value,
            operator=operator,
            data_state=data_state,
            _configuration=_configuration,
        )

from openapi_client.model.data_state_type import DataStateType
from openapi_client.model.operator_enum import OperatorEnum



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class NodeType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "Activation": "ACTIVATION",
            "ActivityRegularization": "ACTIVITY_REGULARIZATION",
            "Add": "ADD",
            "AdditiveAttention": "ADDITIVE_ATTENTION",
            "AlphaDropout": "ALPHA_DROPOUT",
            "Average": "AVERAGE",
            "AveragePooling1D": "AVERAGE_POOLING1D",
            "AveragePooling2D": "AVERAGE_POOLING2D",
            "AveragePooling3D": "AVERAGE_POOLING3D",
            "BatchNormalization": "BATCH_NORMALIZATION",
            "Bidirectional": "BIDIRECTIONAL",
            "CategoryEncoding": "CATEGORY_ENCODING",
            "CenterCrop": "CENTER_CROP",
            "Concatenate": "CONCATENATE",
            "Conv1D": "CONV1D",
            "Conv1DTranspose": "CONV1DTRANSPOSE",
            "Conv2D": "CONV2D",
            "Conv2DTranspose": "CONV2DTRANSPOSE",
            "Conv3D": "CONV3D",
            "Conv3DTranspose": "CONV3DTRANSPOSE",
            "ConvLSTM1D": "CONV_LSTM1D",
            "ConvLSTM2D": "CONV_LSTM2D",
            "ConvLSTM3D": "CONV_LSTM3D",
            "Cropping1D": "CROPPING1D",
            "Cropping2D": "CROPPING2D",
            "Cropping3D": "CROPPING3D",
            "CuDNNGRU": "CU_DNNGRU",
            "CuDNNLSTM": "CU_DNNLSTM",
            "Dense": "DENSE",
            "DepthwiseConv1D": "DEPTHWISE_CONV1D",
            "DepthwiseConv2D": "DEPTHWISE_CONV2D",
            "Discretization": "DISCRETIZATION",
            "Dot": "DOT",
            "Dropout": "DROPOUT",
            "ELU": "ELU",
            "Embedding": "EMBEDDING",
            "Flatten": "FLATTEN",
            "GRU": "GRU",
            "GRUCell": "GRUCELL",
            "GRUCellV1": "GRUCELL_V1",
            "GRUCellV2": "GRUCELL_V2",
            "GRUV1": "GRUV1",
            "GRUV2": "GRUV2",
            "GaussianDropout": "GAUSSIAN_DROPOUT",
            "GaussianNoise": "GAUSSIAN_NOISE",
            "GlobalAveragePooling1D": "GLOBAL_AVERAGE_POOLING1D",
            "GlobalAveragePooling2D": "GLOBAL_AVERAGE_POOLING2D",
            "GlobalAveragePooling3D": "GLOBAL_AVERAGE_POOLING3D",
            "GlobalMaxPooling1D": "GLOBAL_MAX_POOLING1D",
            "GlobalMaxPooling2D": "GLOBAL_MAX_POOLING2D",
            "GlobalMaxPooling3D": "GLOBAL_MAX_POOLING3D",
            "GroupNormalization": "GROUP_NORMALIZATION",
            "IntegerLookup": "INTEGER_LOOKUP",
            "LSTM": "LSTM",
            "LSTMCell": "LSTMCELL",
            "LSTMCellV1": "LSTMCELL_V1",
            "LSTMCellV2": "LSTMCELL_V2",
            "LSTMV1": "LSTMV1",
            "LSTMV2": "LSTMV2",
            "LayerNormalization": "LAYER_NORMALIZATION",
            "LeakyReLU": "LEAKY_RE_LU",
            "LocallyConnected1D": "LOCALLY_CONNECTED1D",
            "LocallyConnected2D": "LOCALLY_CONNECTED2D",
            "Masking": "MASKING",
            "MaxPooling1D": "MAX_POOLING1D",
            "MaxPooling2D": "MAX_POOLING2D",
            "MaxPooling3D": "MAX_POOLING3D",
            "Maximum": "MAXIMUM",
            "Minimum": "MINIMUM",
            "MultiHeadAttention": "MULTI_HEAD_ATTENTION",
            "Multiply": "MULTIPLY",
            "Normalization": "NORMALIZATION",
            "PReLU": "PRE_LU",
            "Permute": "PERMUTE",
            "RandomBrightness": "RANDOM_BRIGHTNESS",
            "RandomContrast": "RANDOM_CONTRAST",
            "RandomCrop": "RANDOM_CROP",
            "RandomFlip": "RANDOM_FLIP",
            "RandomFourierFeatures": "RANDOM_FOURIER_FEATURES",
            "RandomHeight": "RANDOM_HEIGHT",
            "RandomRotation": "RANDOM_ROTATION",
            "RandomTranslation": "RANDOM_TRANSLATION",
            "RandomWidth": "RANDOM_WIDTH",
            "RandomZoom": "RANDOM_ZOOM",
            "ReLU": "RE_LU",
            "RepeatVector": "REPEAT_VECTOR",
            "Reshape": "RESHAPE",
            "Resizing": "RESIZING",
            "SeparableConv1D": "SEPARABLE_CONV1D",
            "SeparableConv2D": "SEPARABLE_CONV2D",
            "SimpleRNN": "SIMPLE_RNN",
            "SimpleRNNCell": "SIMPLE_RNNCELL",
            "Softmax": "SOFTMAX",
            "SpatialDropout1D": "SPATIAL_DROPOUT1D",
            "SpatialDropout2D": "SPATIAL_DROPOUT2D",
            "SpatialDropout3D": "SPATIAL_DROPOUT3D",
            "StringLookup": "STRING_LOOKUP",
            "Subtract": "SUBTRACT",
            "SyncBatchNormalization": "SYNC_BATCH_NORMALIZATION",
            "TextVectorization": "TEXT_VECTORIZATION",
            "ThresholdedReLU": "THRESHOLDED_RE_LU",
            "TimeDistributed": "TIME_DISTRIBUTED",
            "UnitNormalization": "UNIT_NORMALIZATION",
            "UpSampling1D": "UP_SAMPLING1D",
            "UpSampling2D": "UP_SAMPLING2D",
            "UpSampling3D": "UP_SAMPLING3D",
            "ZeroPadding1D": "ZERO_PADDING1D",
            "ZeroPadding2D": "ZERO_PADDING2D",
            "ZeroPadding3D": "ZERO_PADDING3D",
            "BinaryCrossentropy": "BINARY_CROSSENTROPY",
            "BinaryFocalCrossentropy": "BINARY_FOCAL_CROSSENTROPY",
            "CategoricalCrossentropy": "CATEGORICAL_CROSSENTROPY",
            "CategoricalHinge": "CATEGORICAL_HINGE",
            "CosineSimilarity": "COSINE_SIMILARITY",
            "Hinge": "HINGE",
            "Huber": "HUBER",
            "KLDivergence": "KLDIVERGENCE",
            "LogCosh": "LOG_COSH",
            "MeanAbsoluteError": "MEAN_ABSOLUTE_ERROR",
            "MeanAbsolutePercentageError": "MEAN_ABSOLUTE_PERCENTAGE_ERROR",
            "MeanSquaredError": "MEAN_SQUARED_ERROR",
            "MeanSquaredLogarithmicError": "MEAN_SQUARED_LOGARITHMIC_ERROR",
            "Poisson": "POISSON",
            "SquaredHinge": "SQUARED_HINGE",
            "Adadelta": "ADADELTA",
            "Adagrad": "ADAGRAD",
            "Adam": "ADAM",
            "Adamax": "ADAMAX",
            "Ftrl": "FTRL",
            "Nadam": "NADAM",
            "RMSprop": "RMSPROP",
            "SGD": "SGD",
            "OnnxAbs": "ONNX_ABS",
            "OnnxErf": "ONNX_ERF",
            "OnnxHardSigmoid": "ONNX_HARD_SIGMOID",
            "OnnxReduceMean": "ONNX_REDUCE_MEAN",
            "OnnxSqrt": "ONNX_SQRT",
            "Dataset": "DATASET",
            "RepresentationBlock": "REPRESENTATION_BLOCK",
            "GroundTruth": "GROUND_TRUTH",
            "CustomLayer": "CUSTOM_LAYER",
            "CustomLoss": "CUSTOM_LOSS",
            "Visualizer": "VISUALIZER",
            "Lambda": "LAMBDA",
            "TFOpLambda": "TFOP_LAMBDA",
            "SlicingOpLambda": "SLICING_OP_LAMBDA",
            "Repeat": "REPEAT",
            "Variable": "VARIABLE",
            "Gather": "GATHER",
            "FixedDropout": "FIXED_DROPOUT",
        }
    
    @schemas.classproperty
    def ACTIVATION(cls):
        return cls("Activation")
    
    @schemas.classproperty
    def ACTIVITY_REGULARIZATION(cls):
        return cls("ActivityRegularization")
    
    @schemas.classproperty
    def ADD(cls):
        return cls("Add")
    
    @schemas.classproperty
    def ADDITIVE_ATTENTION(cls):
        return cls("AdditiveAttention")
    
    @schemas.classproperty
    def ALPHA_DROPOUT(cls):
        return cls("AlphaDropout")
    
    @schemas.classproperty
    def AVERAGE(cls):
        return cls("Average")
    
    @schemas.classproperty
    def AVERAGE_POOLING1D(cls):
        return cls("AveragePooling1D")
    
    @schemas.classproperty
    def AVERAGE_POOLING2D(cls):
        return cls("AveragePooling2D")
    
    @schemas.classproperty
    def AVERAGE_POOLING3D(cls):
        return cls("AveragePooling3D")
    
    @schemas.classproperty
    def BATCH_NORMALIZATION(cls):
        return cls("BatchNormalization")
    
    @schemas.classproperty
    def BIDIRECTIONAL(cls):
        return cls("Bidirectional")
    
    @schemas.classproperty
    def CATEGORY_ENCODING(cls):
        return cls("CategoryEncoding")
    
    @schemas.classproperty
    def CENTER_CROP(cls):
        return cls("CenterCrop")
    
    @schemas.classproperty
    def CONCATENATE(cls):
        return cls("Concatenate")
    
    @schemas.classproperty
    def CONV1D(cls):
        return cls("Conv1D")
    
    @schemas.classproperty
    def CONV1DTRANSPOSE(cls):
        return cls("Conv1DTranspose")
    
    @schemas.classproperty
    def CONV2D(cls):
        return cls("Conv2D")
    
    @schemas.classproperty
    def CONV2DTRANSPOSE(cls):
        return cls("Conv2DTranspose")
    
    @schemas.classproperty
    def CONV3D(cls):
        return cls("Conv3D")
    
    @schemas.classproperty
    def CONV3DTRANSPOSE(cls):
        return cls("Conv3DTranspose")
    
    @schemas.classproperty
    def CONV_LSTM1D(cls):
        return cls("ConvLSTM1D")
    
    @schemas.classproperty
    def CONV_LSTM2D(cls):
        return cls("ConvLSTM2D")
    
    @schemas.classproperty
    def CONV_LSTM3D(cls):
        return cls("ConvLSTM3D")
    
    @schemas.classproperty
    def CROPPING1D(cls):
        return cls("Cropping1D")
    
    @schemas.classproperty
    def CROPPING2D(cls):
        return cls("Cropping2D")
    
    @schemas.classproperty
    def CROPPING3D(cls):
        return cls("Cropping3D")
    
    @schemas.classproperty
    def CU_DNNGRU(cls):
        return cls("CuDNNGRU")
    
    @schemas.classproperty
    def CU_DNNLSTM(cls):
        return cls("CuDNNLSTM")
    
    @schemas.classproperty
    def DENSE(cls):
        return cls("Dense")
    
    @schemas.classproperty
    def DEPTHWISE_CONV1D(cls):
        return cls("DepthwiseConv1D")
    
    @schemas.classproperty
    def DEPTHWISE_CONV2D(cls):
        return cls("DepthwiseConv2D")
    
    @schemas.classproperty
    def DISCRETIZATION(cls):
        return cls("Discretization")
    
    @schemas.classproperty
    def DOT(cls):
        return cls("Dot")
    
    @schemas.classproperty
    def DROPOUT(cls):
        return cls("Dropout")
    
    @schemas.classproperty
    def ELU(cls):
        return cls("ELU")
    
    @schemas.classproperty
    def EMBEDDING(cls):
        return cls("Embedding")
    
    @schemas.classproperty
    def FLATTEN(cls):
        return cls("Flatten")
    
    @schemas.classproperty
    def GRU(cls):
        return cls("GRU")
    
    @schemas.classproperty
    def GRUCELL(cls):
        return cls("GRUCell")
    
    @schemas.classproperty
    def GRUCELL_V1(cls):
        return cls("GRUCellV1")
    
    @schemas.classproperty
    def GRUCELL_V2(cls):
        return cls("GRUCellV2")
    
    @schemas.classproperty
    def GRUV1(cls):
        return cls("GRUV1")
    
    @schemas.classproperty
    def GRUV2(cls):
        return cls("GRUV2")
    
    @schemas.classproperty
    def GAUSSIAN_DROPOUT(cls):
        return cls("GaussianDropout")
    
    @schemas.classproperty
    def GAUSSIAN_NOISE(cls):
        return cls("GaussianNoise")
    
    @schemas.classproperty
    def GLOBAL_AVERAGE_POOLING1D(cls):
        return cls("GlobalAveragePooling1D")
    
    @schemas.classproperty
    def GLOBAL_AVERAGE_POOLING2D(cls):
        return cls("GlobalAveragePooling2D")
    
    @schemas.classproperty
    def GLOBAL_AVERAGE_POOLING3D(cls):
        return cls("GlobalAveragePooling3D")
    
    @schemas.classproperty
    def GLOBAL_MAX_POOLING1D(cls):
        return cls("GlobalMaxPooling1D")
    
    @schemas.classproperty
    def GLOBAL_MAX_POOLING2D(cls):
        return cls("GlobalMaxPooling2D")
    
    @schemas.classproperty
    def GLOBAL_MAX_POOLING3D(cls):
        return cls("GlobalMaxPooling3D")
    
    @schemas.classproperty
    def GROUP_NORMALIZATION(cls):
        return cls("GroupNormalization")
    
    @schemas.classproperty
    def INTEGER_LOOKUP(cls):
        return cls("IntegerLookup")
    
    @schemas.classproperty
    def LSTM(cls):
        return cls("LSTM")
    
    @schemas.classproperty
    def LSTMCELL(cls):
        return cls("LSTMCell")
    
    @schemas.classproperty
    def LSTMCELL_V1(cls):
        return cls("LSTMCellV1")
    
    @schemas.classproperty
    def LSTMCELL_V2(cls):
        return cls("LSTMCellV2")
    
    @schemas.classproperty
    def LSTMV1(cls):
        return cls("LSTMV1")
    
    @schemas.classproperty
    def LSTMV2(cls):
        return cls("LSTMV2")
    
    @schemas.classproperty
    def LAYER_NORMALIZATION(cls):
        return cls("LayerNormalization")
    
    @schemas.classproperty
    def LEAKY_RE_LU(cls):
        return cls("LeakyReLU")
    
    @schemas.classproperty
    def LOCALLY_CONNECTED1D(cls):
        return cls("LocallyConnected1D")
    
    @schemas.classproperty
    def LOCALLY_CONNECTED2D(cls):
        return cls("LocallyConnected2D")
    
    @schemas.classproperty
    def MASKING(cls):
        return cls("Masking")
    
    @schemas.classproperty
    def MAX_POOLING1D(cls):
        return cls("MaxPooling1D")
    
    @schemas.classproperty
    def MAX_POOLING2D(cls):
        return cls("MaxPooling2D")
    
    @schemas.classproperty
    def MAX_POOLING3D(cls):
        return cls("MaxPooling3D")
    
    @schemas.classproperty
    def MAXIMUM(cls):
        return cls("Maximum")
    
    @schemas.classproperty
    def MINIMUM(cls):
        return cls("Minimum")
    
    @schemas.classproperty
    def MULTI_HEAD_ATTENTION(cls):
        return cls("MultiHeadAttention")
    
    @schemas.classproperty
    def MULTIPLY(cls):
        return cls("Multiply")
    
    @schemas.classproperty
    def NORMALIZATION(cls):
        return cls("Normalization")
    
    @schemas.classproperty
    def PRE_LU(cls):
        return cls("PReLU")
    
    @schemas.classproperty
    def PERMUTE(cls):
        return cls("Permute")
    
    @schemas.classproperty
    def RANDOM_BRIGHTNESS(cls):
        return cls("RandomBrightness")
    
    @schemas.classproperty
    def RANDOM_CONTRAST(cls):
        return cls("RandomContrast")
    
    @schemas.classproperty
    def RANDOM_CROP(cls):
        return cls("RandomCrop")
    
    @schemas.classproperty
    def RANDOM_FLIP(cls):
        return cls("RandomFlip")
    
    @schemas.classproperty
    def RANDOM_FOURIER_FEATURES(cls):
        return cls("RandomFourierFeatures")
    
    @schemas.classproperty
    def RANDOM_HEIGHT(cls):
        return cls("RandomHeight")
    
    @schemas.classproperty
    def RANDOM_ROTATION(cls):
        return cls("RandomRotation")
    
    @schemas.classproperty
    def RANDOM_TRANSLATION(cls):
        return cls("RandomTranslation")
    
    @schemas.classproperty
    def RANDOM_WIDTH(cls):
        return cls("RandomWidth")
    
    @schemas.classproperty
    def RANDOM_ZOOM(cls):
        return cls("RandomZoom")
    
    @schemas.classproperty
    def RE_LU(cls):
        return cls("ReLU")
    
    @schemas.classproperty
    def REPEAT_VECTOR(cls):
        return cls("RepeatVector")
    
    @schemas.classproperty
    def RESHAPE(cls):
        return cls("Reshape")
    
    @schemas.classproperty
    def RESIZING(cls):
        return cls("Resizing")
    
    @schemas.classproperty
    def SEPARABLE_CONV1D(cls):
        return cls("SeparableConv1D")
    
    @schemas.classproperty
    def SEPARABLE_CONV2D(cls):
        return cls("SeparableConv2D")
    
    @schemas.classproperty
    def SIMPLE_RNN(cls):
        return cls("SimpleRNN")
    
    @schemas.classproperty
    def SIMPLE_RNNCELL(cls):
        return cls("SimpleRNNCell")
    
    @schemas.classproperty
    def SOFTMAX(cls):
        return cls("Softmax")
    
    @schemas.classproperty
    def SPATIAL_DROPOUT1D(cls):
        return cls("SpatialDropout1D")
    
    @schemas.classproperty
    def SPATIAL_DROPOUT2D(cls):
        return cls("SpatialDropout2D")
    
    @schemas.classproperty
    def SPATIAL_DROPOUT3D(cls):
        return cls("SpatialDropout3D")
    
    @schemas.classproperty
    def STRING_LOOKUP(cls):
        return cls("StringLookup")
    
    @schemas.classproperty
    def SUBTRACT(cls):
        return cls("Subtract")
    
    @schemas.classproperty
    def SYNC_BATCH_NORMALIZATION(cls):
        return cls("SyncBatchNormalization")
    
    @schemas.classproperty
    def TEXT_VECTORIZATION(cls):
        return cls("TextVectorization")
    
    @schemas.classproperty
    def THRESHOLDED_RE_LU(cls):
        return cls("ThresholdedReLU")
    
    @schemas.classproperty
    def TIME_DISTRIBUTED(cls):
        return cls("TimeDistributed")
    
    @schemas.classproperty
    def UNIT_NORMALIZATION(cls):
        return cls("UnitNormalization")
    
    @schemas.classproperty
    def UP_SAMPLING1D(cls):
        return cls("UpSampling1D")
    
    @schemas.classproperty
    def UP_SAMPLING2D(cls):
        return cls("UpSampling2D")
    
    @schemas.classproperty
    def UP_SAMPLING3D(cls):
        return cls("UpSampling3D")
    
    @schemas.classproperty
    def ZERO_PADDING1D(cls):
        return cls("ZeroPadding1D")
    
    @schemas.classproperty
    def ZERO_PADDING2D(cls):
        return cls("ZeroPadding2D")
    
    @schemas.classproperty
    def ZERO_PADDING3D(cls):
        return cls("ZeroPadding3D")
    
    @schemas.classproperty
    def BINARY_CROSSENTROPY(cls):
        return cls("BinaryCrossentropy")
    
    @schemas.classproperty
    def BINARY_FOCAL_CROSSENTROPY(cls):
        return cls("BinaryFocalCrossentropy")
    
    @schemas.classproperty
    def CATEGORICAL_CROSSENTROPY(cls):
        return cls("CategoricalCrossentropy")
    
    @schemas.classproperty
    def CATEGORICAL_HINGE(cls):
        return cls("CategoricalHinge")
    
    @schemas.classproperty
    def COSINE_SIMILARITY(cls):
        return cls("CosineSimilarity")
    
    @schemas.classproperty
    def HINGE(cls):
        return cls("Hinge")
    
    @schemas.classproperty
    def HUBER(cls):
        return cls("Huber")
    
    @schemas.classproperty
    def KLDIVERGENCE(cls):
        return cls("KLDivergence")
    
    @schemas.classproperty
    def LOG_COSH(cls):
        return cls("LogCosh")
    
    @schemas.classproperty
    def MEAN_ABSOLUTE_ERROR(cls):
        return cls("MeanAbsoluteError")
    
    @schemas.classproperty
    def MEAN_ABSOLUTE_PERCENTAGE_ERROR(cls):
        return cls("MeanAbsolutePercentageError")
    
    @schemas.classproperty
    def MEAN_SQUARED_ERROR(cls):
        return cls("MeanSquaredError")
    
    @schemas.classproperty
    def MEAN_SQUARED_LOGARITHMIC_ERROR(cls):
        return cls("MeanSquaredLogarithmicError")
    
    @schemas.classproperty
    def POISSON(cls):
        return cls("Poisson")
    
    @schemas.classproperty
    def SQUARED_HINGE(cls):
        return cls("SquaredHinge")
    
    @schemas.classproperty
    def ADADELTA(cls):
        return cls("Adadelta")
    
    @schemas.classproperty
    def ADAGRAD(cls):
        return cls("Adagrad")
    
    @schemas.classproperty
    def ADAM(cls):
        return cls("Adam")
    
    @schemas.classproperty
    def ADAMAX(cls):
        return cls("Adamax")
    
    @schemas.classproperty
    def FTRL(cls):
        return cls("Ftrl")
    
    @schemas.classproperty
    def NADAM(cls):
        return cls("Nadam")
    
    @schemas.classproperty
    def RMSPROP(cls):
        return cls("RMSprop")
    
    @schemas.classproperty
    def SGD(cls):
        return cls("SGD")
    
    @schemas.classproperty
    def ONNX_ABS(cls):
        return cls("OnnxAbs")
    
    @schemas.classproperty
    def ONNX_ERF(cls):
        return cls("OnnxErf")
    
    @schemas.classproperty
    def ONNX_HARD_SIGMOID(cls):
        return cls("OnnxHardSigmoid")
    
    @schemas.classproperty
    def ONNX_REDUCE_MEAN(cls):
        return cls("OnnxReduceMean")
    
    @schemas.classproperty
    def ONNX_SQRT(cls):
        return cls("OnnxSqrt")
    
    @schemas.classproperty
    def DATASET(cls):
        return cls("Dataset")
    
    @schemas.classproperty
    def REPRESENTATION_BLOCK(cls):
        return cls("RepresentationBlock")
    
    @schemas.classproperty
    def GROUND_TRUTH(cls):
        return cls("GroundTruth")
    
    @schemas.classproperty
    def CUSTOM_LAYER(cls):
        return cls("CustomLayer")
    
    @schemas.classproperty
    def CUSTOM_LOSS(cls):
        return cls("CustomLoss")
    
    @schemas.classproperty
    def VISUALIZER(cls):
        return cls("Visualizer")
    
    @schemas.classproperty
    def LAMBDA(cls):
        return cls("Lambda")
    
    @schemas.classproperty
    def TFOP_LAMBDA(cls):
        return cls("TFOpLambda")
    
    @schemas.classproperty
    def SLICING_OP_LAMBDA(cls):
        return cls("SlicingOpLambda")
    
    @schemas.classproperty
    def REPEAT(cls):
        return cls("Repeat")
    
    @schemas.classproperty
    def VARIABLE(cls):
        return cls("Variable")
    
    @schemas.classproperty
    def GATHER(cls):
        return cls("Gather")
    
    @schemas.classproperty
    def FIXED_DROPOUT(cls):
        return cls("FixedDropout")



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class YMetaAxis(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    DisplayName is the name shown on the Y column
Domain sets the axis range (domain equal to min:0 and max:100 will have a range of values between 0 and 100). The default domain causes 'datamin' and 'datamax' causes the webui to calculate the domain.
   TODO: look into if the domain can be removed from the interface and calculated by recharts only.
Metrics is a list of the different labels (one for each line)
MetaFields is a list of the metadata that will be added to each point and will apear in the chart tooltip
    """


    class MetaOapg:
        required = {
            "displayName",
            "domain",
            "metaFields",
            "metrics",
        }
        
        class properties:
            
            
            class metaFields(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'metaFields':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class metrics(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'metrics':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
        
            @staticmethod
            def domain() -> typing.Type['Domain']:
                return Domain
            displayName = schemas.StrSchema
            __annotations__ = {
                "metaFields": metaFields,
                "metrics": metrics,
                "domain": domain,
                "displayName": displayName,
            }
    
    displayName: MetaOapg.properties.displayName
    domain: 'Domain'
    metaFields: MetaOapg.properties.metaFields
    metrics: MetaOapg.properties.metrics
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metaFields"]) -> MetaOapg.properties.metaFields: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metrics"]) -> MetaOapg.properties.metrics: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["domain"]) -> 'Domain': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["displayName"]) -> MetaOapg.properties.displayName: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["metaFields", "metrics", "domain", "displayName", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metaFields"]) -> MetaOapg.properties.metaFields: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metrics"]) -> MetaOapg.properties.metrics: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["domain"]) -> 'Domain': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["displayName"]) -> MetaOapg.properties.displayName: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["metaFields", "metrics", "domain", "displayName", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        displayName: typing.Union[MetaOapg.properties.displayName, str, ],
        domain: 'Domain',
        metaFields: typing.Union[MetaOapg.properties.metaFields, list, tuple, ],
        metrics: typing.Union[MetaOapg.properties.metrics, list, tuple, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'YMetaAxis':
        return super().__new__(
            cls,
            *args,
            displayName=displayName,
            domain=domain,
            metaFields=metaFields,
            metrics=metrics,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_client.model.domain import Domain



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class TrainingParams(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "batch_size",
            "epochs",
        }
        
        class properties:
            epochs = schemas.Float64Schema
            batch_size = schemas.Float64Schema
        
            @staticmethod
            def early_stop_params() -> typing.Type['EarlyStopParams']:
                return EarlyStopParams
            __annotations__ = {
                "epochs": epochs,
                "batch_size": batch_size,
                "early_stop_params": early_stop_params,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    batch_size: MetaOapg.properties.batch_size
    epochs: MetaOapg.properties.epochs
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["batch_size"]) -> MetaOapg.properties.batch_size: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["epochs"]) -> MetaOapg.properties.epochs: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["early_stop_params"]) -> 'EarlyStopParams': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["batch_size"], typing_extensions.Literal["epochs"], typing_extensions.Literal["early_stop_params"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["batch_size"]) -> MetaOapg.properties.batch_size: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["epochs"]) -> MetaOapg.properties.epochs: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["early_stop_params"]) -> typing.Union['EarlyStopParams', schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["batch_size"], typing_extensions.Literal["epochs"], typing_extensions.Literal["early_stop_params"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        batch_size: typing.Union[MetaOapg.properties.batch_size, decimal.Decimal, int, float, ],
        epochs: typing.Union[MetaOapg.properties.epochs, decimal.Decimal, int, float, ],
        early_stop_params: typing.Union['EarlyStopParams', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'TrainingParams':
        return super().__new__(
            cls,
            *args,
            batch_size=batch_size,
            epochs=epochs,
            early_stop_params=early_stop_params,
            _configuration=_configuration,
        )

from openapi_client.model.early_stop_params import EarlyStopParams



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class TrainFromInitialWeightsParams(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "fromEpoch",
            "fromModelId",
            "modelName",
            "versionId",
            "trainingParams",
            "shouldRunPopulationExploration",
        }
        
        class properties:
            versionId = schemas.StrSchema
            fromModelId = schemas.StrSchema
            fromEpoch = schemas.Float64Schema
            modelName = schemas.StrSchema
        
            @staticmethod
            def trainingParams() -> typing.Type['TrainingParams']:
                return TrainingParams
            shouldRunPopulationExploration = schemas.BoolSchema
            __annotations__ = {
                "versionId": versionId,
                "fromModelId": fromModelId,
                "fromEpoch": fromEpoch,
                "modelName": modelName,
                "trainingParams": trainingParams,
                "shouldRunPopulationExploration": shouldRunPopulationExploration,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    fromEpoch: MetaOapg.properties.fromEpoch
    fromModelId: MetaOapg.properties.fromModelId
    modelName: MetaOapg.properties.modelName
    versionId: MetaOapg.properties.versionId
    trainingParams: 'TrainingParams'
    shouldRunPopulationExploration: MetaOapg.properties.shouldRunPopulationExploration
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fromEpoch"]) -> MetaOapg.properties.fromEpoch: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fromModelId"]) -> MetaOapg.properties.fromModelId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["modelName"]) -> MetaOapg.properties.modelName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["versionId"]) -> MetaOapg.properties.versionId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["trainingParams"]) -> 'TrainingParams': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["shouldRunPopulationExploration"]) -> MetaOapg.properties.shouldRunPopulationExploration: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["fromEpoch"], typing_extensions.Literal["fromModelId"], typing_extensions.Literal["modelName"], typing_extensions.Literal["versionId"], typing_extensions.Literal["trainingParams"], typing_extensions.Literal["shouldRunPopulationExploration"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fromEpoch"]) -> MetaOapg.properties.fromEpoch: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fromModelId"]) -> MetaOapg.properties.fromModelId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["modelName"]) -> MetaOapg.properties.modelName: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["versionId"]) -> MetaOapg.properties.versionId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["trainingParams"]) -> 'TrainingParams': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["shouldRunPopulationExploration"]) -> MetaOapg.properties.shouldRunPopulationExploration: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["fromEpoch"], typing_extensions.Literal["fromModelId"], typing_extensions.Literal["modelName"], typing_extensions.Literal["versionId"], typing_extensions.Literal["trainingParams"], typing_extensions.Literal["shouldRunPopulationExploration"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        fromEpoch: typing.Union[MetaOapg.properties.fromEpoch, decimal.Decimal, int, float, ],
        fromModelId: typing.Union[MetaOapg.properties.fromModelId, str, ],
        modelName: typing.Union[MetaOapg.properties.modelName, str, ],
        versionId: typing.Union[MetaOapg.properties.versionId, str, ],
        trainingParams: 'TrainingParams',
        shouldRunPopulationExploration: typing.Union[MetaOapg.properties.shouldRunPopulationExploration, bool, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'TrainFromInitialWeightsParams':
        return super().__new__(
            cls,
            *args,
            fromEpoch=fromEpoch,
            fromModelId=fromModelId,
            modelName=modelName,
            versionId=versionId,
            trainingParams=trainingParams,
            shouldRunPopulationExploration=shouldRunPopulationExploration,
            _configuration=_configuration,
        )

from openapi_client.model.training_params import TrainingParams



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class JobNotificationLeepScriptContext(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "jobId",
            "leepScriptName",
            "jobType",
            "leepScriptId",
        }
        
        class properties:
            leepScriptId = schemas.StrSchema
            leepScriptName = schemas.StrSchema
        
            @staticmethod
            def jobType() -> typing.Type['JobTypeEnum']:
                return JobTypeEnum
            jobId = schemas.StrSchema
            leepScriptVersionId = schemas.StrSchema
            leepScriptVersion = schemas.StrSchema
            __annotations__ = {
                "leepScriptId": leepScriptId,
                "leepScriptName": leepScriptName,
                "jobType": jobType,
                "jobId": jobId,
                "leepScriptVersionId": leepScriptVersionId,
                "leepScriptVersion": leepScriptVersion,
            }
    
    jobId: MetaOapg.properties.jobId
    leepScriptName: MetaOapg.properties.leepScriptName
    jobType: 'JobTypeEnum'
    leepScriptId: MetaOapg.properties.leepScriptId
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["leepScriptId"]) -> MetaOapg.properties.leepScriptId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["leepScriptName"]) -> MetaOapg.properties.leepScriptName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["jobType"]) -> 'JobTypeEnum': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["jobId"]) -> MetaOapg.properties.jobId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["leepScriptVersionId"]) -> MetaOapg.properties.leepScriptVersionId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["leepScriptVersion"]) -> MetaOapg.properties.leepScriptVersion: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["leepScriptId", "leepScriptName", "jobType", "jobId", "leepScriptVersionId", "leepScriptVersion", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["leepScriptId"]) -> MetaOapg.properties.leepScriptId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["leepScriptName"]) -> MetaOapg.properties.leepScriptName: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["jobType"]) -> 'JobTypeEnum': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["jobId"]) -> MetaOapg.properties.jobId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["leepScriptVersionId"]) -> typing.Union[MetaOapg.properties.leepScriptVersionId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["leepScriptVersion"]) -> typing.Union[MetaOapg.properties.leepScriptVersion, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["leepScriptId", "leepScriptName", "jobType", "jobId", "leepScriptVersionId", "leepScriptVersion", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        jobId: typing.Union[MetaOapg.properties.jobId, str, ],
        leepScriptName: typing.Union[MetaOapg.properties.leepScriptName, str, ],
        jobType: 'JobTypeEnum',
        leepScriptId: typing.Union[MetaOapg.properties.leepScriptId, str, ],
        leepScriptVersionId: typing.Union[MetaOapg.properties.leepScriptVersionId, str, schemas.Unset] = schemas.unset,
        leepScriptVersion: typing.Union[MetaOapg.properties.leepScriptVersion, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'JobNotificationLeepScriptContext':
        return super().__new__(
            cls,
            *args,
            jobId=jobId,
            leepScriptName=leepScriptName,
            jobType=jobType,
            leepScriptId=leepScriptId,
            leepScriptVersionId=leepScriptVersionId,
            leepScriptVersion=leepScriptVersion,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_client.model.job_type_enum import JobTypeEnum



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

import unittest

import openapi_client
from openapi_client.model.visualization_response import VisualizationResponse
from openapi_client import configuration


class TestVisualizationResponse(unittest.TestCase):
    """VisualizationResponse unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_client.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    AUTH_KEYLOGIN = "/auth/keylogin"
    AUTH_LOGIN = "/auth/login"
    AUTH_KEYGEN = "/auth/keygen"
    AUTH_WHO_AM_I = "/auth/whoAmI"
    AUTH_SIGNUP = "/auth/signup"
    AUTH_ACTIVATE = "/auth/activate"
    AUTH_RESEND_ACTIVATION_MAIL = "/auth/resendActivationMail"
    AUTH_SEND_RESET_PASSWORD_MAIL = "/auth/sendResetPasswordMail"
    AUTH_RESET_PASSWORD = "/auth/resetPassword"
    AUTH_SET_USER_METADATA = "/auth/setUserMetadata"
    AUTH_REQUEST_TRIAL = "/auth/requestTrial"
    AUTH_START_TRIAL = "/auth/startTrial"
    AUTH_EXTEND_TRIAL = "/auth/extendTrial"
    AUTH_LOGOUT = "/auth/logout"
    DASHBOARDS_GET_KIBANA_DASHBOARDS = "/dashboards/getKibanaDashboards"
    DASHBOARDS_GET_PROJECT_DASHBOARDS = "/dashboards/getProjectDashboards"
    DASHBOARDS_GET_DASHBOARD = "/dashboards/getDashboard"
    DASHBOARDS_ADD_DASHBOARD = "/dashboards/addDashboard"
    DASHBOARDS_DELETE_DASHBOARD = "/dashboards/deleteDashboard"
    DASHBOARDS_UPDATE_DASHBOARD = "/dashboards/updateDashboard"
    DASHBOARDS_GET_KIBANA_DASHLET_FIELDS = "/dashboards/getKibanaDashletFields"
    DASHBOARDS_GET_DASHLET_FIELDS = "/dashboards/getDashletFields"
    DATASETS_GET_DATASETS = "/datasets/getDatasets"
    DATASETS_ADD_DATASET = "/datasets/addDataset"
    DATASETS_TRASH_DATASET = "/datasets/trashDataset"
    DATASETS_SAVE_DATASET_VERSION = "/datasets/saveDatasetVersion"
    DATASETS_MODIFY_DATASET_VERSION_NOTE = "/datasets/modifyDatasetVersionNote"
    DATASETS_PARSE_DATASET = "/datasets/parseDataset"
    DATASETS_GET_DATASET_VERSION = "/datasets/getDatasetVersion"
    DATASETS_GET_LATEST_DATASET_VERSION = "/datasets/getLatestDatasetVersion"
    DATASETS_GET_DATASET_VERSIONS = "/datasets/getDatasetVersions"
    DEMOS_GET_DEMOS = "/demos/getDemos"
    DEMOS_IMPORT_DEMO_PROJECT = "/demos/importDemoProject"
    DEMOS_SEND_USER_MESSAGE = "/demos/sendUserMessage"
    EXPORTEDMODELS_GET_EXPORTED_MODEL_JOBS = "/exportedmodels/getExportedModelJobs"
    EXPORTEDMODELS_GET_STORED_EXPORTED_MODEL_RESOURCE_URL = "/exportedmodels/getStoredExportedModelResourceUrl"
    INSIGHTS_GET_MODEL_INSIGHTS = "/insights/getModelInsights"
    ISSUES_GET_PROJECT_ISSUES = "/issues/getProjectIssues"
    ISSUES_GET_SINGLE_ISSUE = "/issues/getSingleIssue"
    ISSUES_UPDATE_ISSUE = "/issues/updateIssue"
    ISSUES_ADD_ISSUE = "/issues/addIssue"
    ISSUES_DELETE_ISSUE = "/issues/deleteIssue"
    JOBS_GET_JOBS = "/jobs/getJobs"
    JOBS_GET_TRAINING_JOBS = "/jobs/getTrainingJobs"
    JOBS_IS_TRAINING_JOB_RUNNING = "/jobs/isTrainingJobRunning"
    JOBS_GET_ORGANIZATION_JOBS = "/jobs/getOrganizationJobs"
    JOBS_STOP_JOB = "/jobs/stopJob"
    JOBS_TERMINATE_JOB = "/jobs/terminateJob"
    JOBS_WARMUP = "/jobs/warmup"
    JOBS_ADD_EXPORT_MODEL_JOB = "/jobs/addExportModelJob"
    JOBS_TRAIN_FROM_SCRATCH = "/jobs/trainFromScratch"
    JOBS_CONTINUE_TRAIN = "/jobs/continueTrain"
    JOBS_TRAIN_FROM_INITIAL_WEIGHTS = "/jobs/trainFromInitialWeights"
    JOBS_EVALUATE = "/jobs/evaluate"
    JOBS_SAMPLE_ANALYSIS = "/jobs/sampleAnalysis"
    JOBS_POPULATION_EXPLORATION = "/jobs/populationExploration"
    JOBS_SAMPLE_SELECTION = "/jobs/sampleSelection"
    JOBS_GET_MACHINE_TYPES = "/jobs/getMachineTypes"
    JOBS_SET_MACHINE_TYPE = "/jobs/setMachineType"
    METADATA_GET_MAX_ACTIVE_USERS = "/metadata/getMaxActiveUsers"
    METADATA_GET_STATISTICS = "/metadata/getStatistics"
    MODELTESTS_CREATE_MODEL_TEST = "/model-tests/createModelTest"
    MODELTESTS_UPDATE_MODEL_TEST = "/model-tests/updateModelTest"
    MODELTESTS_GET_SINGLE_MODEL_TEST = "/model-tests/getSingleModelTest"
    MODELTESTS_GET_ALL_PROJECT_MODEL_TESTS = "/model-tests/getAllProjectModelTests"
    MODELTESTS_DELETE_MODEL_TEST = "/model-tests/deleteModelTest"
    MODELTESTS_GET_MODEL_TEST_RESULT = "/model-tests/getModelTestResult"
    MODELMETRICS_GET_MODEL_EPOCH_LOSS = "/modelmetrics/getModelEpochLoss"
    MODELMETRICS_GET_XYCHART = "/modelmetrics/getXYChart"
    MODELMETRICS_GET_HEATMAP_CHART = "/modelmetrics/getHeatmapChart"
    MODELMETRICS_GET_TABLE_CHART = "/modelmetrics/getTableChart"
    MODELMETRICS_GET_CONFUSION_METRIC_NAMES = "/modelmetrics/getConfusionMetricNames"
    MODELMETRICS_GET_BALANCED_ACCURACY = "/modelmetrics/getBalancedAccuracy"
    MODELMETRICS_GET_F1SCORE = "/modelmetrics/getF1Score"
    MODELMETRICS_GET_PR_CURVE = "/modelmetrics/getPrCurve"
    MODELMETRICS_GET_ROC = "/modelmetrics/getRoc"
    MODELS_GET_MODELS_BY_HASH = "/models/getModelsByHash"
    MODELS_GET_MODELS_BY_VERSION_ID = "/models/getModelsByVersionId"
    MODELS_GET_RECENT_ORGANIZATION_MODELS = "/models/getRecentOrganizationModels"
    MODELS_DELETE_MODEL = "/models/deleteModel"
    MONITOR_HEALTH_CHECK = "/monitor/healthCheck"
    NOTIFICATIONS_GET_NOTIFICATIONS = "/notifications/getNotifications"
    NOTIFICATIONS_SET_USER_NOTIFICATIONS_AS_READ = "/notifications/setUserNotificationsAsRead"
    ORGANIZATIONS_GET_ORGANIZATIONS = "/organizations/getOrganizations"
    ORGANIZATIONS_UPDATE_ORGANIZATION_PUBLIC_NAME = "/organizations/updateOrganizationPublicName"
    ORGANIZATIONS_CREATE_ORGANIZATION = "/organizations/createOrganization"
    ORGANIZATIONS_DELETE_ORGANIZATION = "/organizations/deleteOrganization"
    ORGANIZATIONS_SET_DEFAULT_ORGANIZATION = "/organizations/setDefaultOrganization"
    PROJECTS_ADD_PROJECT = "/projects/addProject"
    PROJECTS_GET_PROJECTS = "/projects/getProjects"
    PROJECTS_LOAD_MODEL = "/projects/loadModel"
    PROJECTS_DELETE_PROJECT = "/projects/deleteProject"
    PROJECTS_TRASH_PROJECT = "/projects/trashProject"
    PROJECTS_GET_CURRENT_PROJECT_VERSION = "/projects/getCurrentProjectVersion"
    SECRETMANAGER_ADD_SECRET_MANAGER = "/secret-manager/addSecretManager"
    SECRETMANAGER_TRASH_SECRET_MANAGER = "/secret-manager/trashSecretManager"
    SECRETMANAGER_GET_SECRET_MANAGER_LIST = "/secret-manager/getSecretManagerList"
    SECRETMANAGER_UPDATE_SECRET_MANAGER = "/secret-manager/updateSecretManager"
    USERS_GET_ORGANIZATION_SLIM_USER_DATA = "/users/getOrganizationSlimUserData"
    USERS_GET_ALL_SLIM_USER_DATA = "/users/getAllSlimUserData"
    USERS_UPDATE_USER_STATUS = "/users/updateUserStatus"
    USERS_UPDATE_USER_ORGANIZATION = "/users/updateUserOrganization"
    USERS_UPDATE_USER_ROLE = "/users/updateUserRole"
    USERS_UPDATE_USER_NAME = "/users/updateUserName"
    USERS_DELETE_USER_BY_ID = "/users/deleteUserById"
    VERSIONS_IMPORT_MODEL = "/versions/importModel"
    VERSIONS_ADD_VERSION = "/versions/addVersion"
    VERSIONS_LOAD_VERSION = "/versions/loadVersion"
    VERSIONS_DELETE_VERSION = "/versions/deleteVersion"
    VERSIONS_UPDATE_VERSION = "/versions/updateVersion"
    VERSIONS_GET_PROJECT_SLIM_VERSIONS = "/versions/getProjectSlimVersions"
    VERSIONS_GET_UPLOAD_SIGNED_URL = "/versions/getUploadSignedUrl"
    VISUALIZATIONS_GET_VISUALIZATION = "/visualizations/getVisualization"
    VISUALIZATIONS_GET_MODEL_VISUALIZATIONS = "/visualizations/getModelVisualizations"
    VISUALIZATIONS_SAVE_ANALYZER_LAYOUT = "/visualizations/saveAnalyzerLayout"
    VISUALIZATIONS_DELETE_VISUALIZATIONS = "/visualizations/deleteVisualizations"
    VISUALIZATIONS_GET_STORED_RESOURCE_URL = "/visualizations/getStoredResourceUrl"



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class IssueActivity(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "actionType",
            "createdAt",
            "createdBy",
            "action",
            "updatedAt",
        }
        
        class properties:
            createdAt = schemas.DateTimeSchema
            updatedAt = schemas.DateTimeSchema
            createdBy = schemas.StrSchema
        
            @staticmethod
            def actionType() -> typing.Type['IssueActionType']:
                return IssueActionType
        
            @staticmethod
            def action() -> typing.Type['IssueAction']:
                return IssueAction
            __annotations__ = {
                "createdAt": createdAt,
                "updatedAt": updatedAt,
                "createdBy": createdBy,
                "actionType": actionType,
                "action": action,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    actionType: 'IssueActionType'
    createdAt: MetaOapg.properties.createdAt
    createdBy: MetaOapg.properties.createdBy
    action: 'IssueAction'
    updatedAt: MetaOapg.properties.updatedAt
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["actionType"]) -> 'IssueActionType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdBy"]) -> MetaOapg.properties.createdBy: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["action"]) -> 'IssueAction': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updatedAt"]) -> MetaOapg.properties.updatedAt: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["actionType"], typing_extensions.Literal["createdAt"], typing_extensions.Literal["createdBy"], typing_extensions.Literal["action"], typing_extensions.Literal["updatedAt"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["actionType"]) -> 'IssueActionType': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdBy"]) -> MetaOapg.properties.createdBy: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["action"]) -> 'IssueAction': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updatedAt"]) -> MetaOapg.properties.updatedAt: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["actionType"], typing_extensions.Literal["createdAt"], typing_extensions.Literal["createdBy"], typing_extensions.Literal["action"], typing_extensions.Literal["updatedAt"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        actionType: 'IssueActionType',
        createdAt: typing.Union[MetaOapg.properties.createdAt, str, datetime, ],
        createdBy: typing.Union[MetaOapg.properties.createdBy, str, ],
        action: 'IssueAction',
        updatedAt: typing.Union[MetaOapg.properties.updatedAt, str, datetime, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'IssueActivity':
        return super().__new__(
            cls,
            *args,
            actionType=actionType,
            createdAt=createdAt,
            createdBy=createdBy,
            action=action,
            updatedAt=updatedAt,
            _configuration=_configuration,
        )

from openapi_client.model.issue_action import IssueAction
from openapi_client.model.issue_action_type import IssueActionType



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class Metric(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "MeanSquaredError": "MEAN_SQUARED_ERROR",
            "MeanSquaredLogarithmicError": "MEAN_SQUARED_LOGARITHMIC_ERROR",
            "MeanAbsoluteError": "MEAN_ABSOLUTE_ERROR",
            "MeanAbsolutePercentageError": "MEAN_ABSOLUTE_PERCENTAGE_ERROR",
            "Accuracy": "ACCURACY",
            "BinaryAccuracy": "BINARY_ACCURACY",
            "MeanIOU": "MEAN_IOU",
            "ConfusionMatrixClassification": "CONFUSION_MATRIX_CLASSIFICATION",
            "ConfusionMatrixBinaryClassification": "CONFUSION_MATRIX_BINARY_CLASSIFICATION",
        }
    
    @schemas.classproperty
    def MEAN_SQUARED_ERROR(cls):
        return cls("MeanSquaredError")
    
    @schemas.classproperty
    def MEAN_SQUARED_LOGARITHMIC_ERROR(cls):
        return cls("MeanSquaredLogarithmicError")
    
    @schemas.classproperty
    def MEAN_ABSOLUTE_ERROR(cls):
        return cls("MeanAbsoluteError")
    
    @schemas.classproperty
    def MEAN_ABSOLUTE_PERCENTAGE_ERROR(cls):
        return cls("MeanAbsolutePercentageError")
    
    @schemas.classproperty
    def ACCURACY(cls):
        return cls("Accuracy")
    
    @schemas.classproperty
    def BINARY_ACCURACY(cls):
        return cls("BinaryAccuracy")
    
    @schemas.classproperty
    def MEAN_IOU(cls):
        return cls("MeanIOU")
    
    @schemas.classproperty
    def CONFUSION_MATRIX_CLASSIFICATION(cls):
        return cls("ConfusionMatrixClassification")
    
    @schemas.classproperty
    def CONFUSION_MATRIX_BINARY_CLASSIFICATION(cls):
        return cls("ConfusionMatrixBinaryClassification")



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class SlimUserDataLocal(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "organization",
            "name",
            "email",
            "activated",
        }
        
        class properties:
            name = schemas.StrSchema
            email = schemas.StrSchema
            organization = schemas.StrSchema
            activated = schemas.BoolSchema
            __annotations__ = {
                "name": name,
                "email": email,
                "organization": organization,
                "activated": activated,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    organization: MetaOapg.properties.organization
    name: MetaOapg.properties.name
    email: MetaOapg.properties.email
    activated: MetaOapg.properties.activated
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["organization"]) -> MetaOapg.properties.organization: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["email"]) -> MetaOapg.properties.email: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["activated"]) -> MetaOapg.properties.activated: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["organization"], typing_extensions.Literal["name"], typing_extensions.Literal["email"], typing_extensions.Literal["activated"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["organization"]) -> MetaOapg.properties.organization: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["email"]) -> MetaOapg.properties.email: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["activated"]) -> MetaOapg.properties.activated: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["organization"], typing_extensions.Literal["name"], typing_extensions.Literal["email"], typing_extensions.Literal["activated"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        organization: typing.Union[MetaOapg.properties.organization, str, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        email: typing.Union[MetaOapg.properties.email, str, ],
        activated: typing.Union[MetaOapg.properties.activated, bool, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'SlimUserDataLocal':
        return super().__new__(
            cls,
            *args,
            organization=organization,
            name=name,
            email=email,
            activated=activated,
            _configuration=_configuration,
        )



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_client.paths.metadata_get_max_active_users import Api

from openapi_client.paths import PathValues

path = PathValues.METADATA_GET_MAX_ACTIVE_USERS


# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class BucketAggregation(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "orderParams",
            "xField",
            "dataDistributionType",
            "xAxisSizeInterval",
        }
        
        class properties:
            xField = schemas.StrSchema
        
            @staticmethod
            def dataDistributionType() -> typing.Type['DataDistributionType']:
                return DataDistributionType
            xAxisSizeInterval = schemas.Float64Schema
            
            
            class orderParams(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "asc": "ASC",
                        "desc": "DESC",
                    }
                
                @schemas.classproperty
                def ASC(cls):
                    return cls("asc")
                
                @schemas.classproperty
                def DESC(cls):
                    return cls("desc")
            __annotations__ = {
                "xField": xField,
                "dataDistributionType": dataDistributionType,
                "xAxisSizeInterval": xAxisSizeInterval,
                "orderParams": orderParams,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    orderParams: MetaOapg.properties.orderParams
    xField: MetaOapg.properties.xField
    dataDistributionType: 'DataDistributionType'
    xAxisSizeInterval: MetaOapg.properties.xAxisSizeInterval
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["orderParams"]) -> MetaOapg.properties.orderParams: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["xField"]) -> MetaOapg.properties.xField: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["dataDistributionType"]) -> 'DataDistributionType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["xAxisSizeInterval"]) -> MetaOapg.properties.xAxisSizeInterval: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["orderParams"], typing_extensions.Literal["xField"], typing_extensions.Literal["dataDistributionType"], typing_extensions.Literal["xAxisSizeInterval"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["orderParams"]) -> MetaOapg.properties.orderParams: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["xField"]) -> MetaOapg.properties.xField: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["dataDistributionType"]) -> 'DataDistributionType': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["xAxisSizeInterval"]) -> MetaOapg.properties.xAxisSizeInterval: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["orderParams"], typing_extensions.Literal["xField"], typing_extensions.Literal["dataDistributionType"], typing_extensions.Literal["xAxisSizeInterval"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        orderParams: typing.Union[MetaOapg.properties.orderParams, str, ],
        xField: typing.Union[MetaOapg.properties.xField, str, ],
        dataDistributionType: 'DataDistributionType',
        xAxisSizeInterval: typing.Union[MetaOapg.properties.xAxisSizeInterval, decimal.Decimal, int, float, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'BucketAggregation':
        return super().__new__(
            cls,
            *args,
            orderParams=orderParams,
            xField=xField,
            dataDistributionType=dataDistributionType,
            xAxisSizeInterval=xAxisSizeInterval,
            _configuration=_configuration,
        )

from openapi_client.model.data_distribution_type import DataDistributionType



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class DatasetMetadata(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "script",
        }
        
        class properties:
            script = schemas.StrSchema
        
            @staticmethod
            def setup() -> typing.Type['DatasetSetup']:
                return DatasetSetup
        
            @staticmethod
            def setupStatus() -> typing.Type['DatasetSetupStatus']:
                return DatasetSetupStatus
        
            @staticmethod
            def modelSetup() -> typing.Type['ModelSetup']:
                return ModelSetup
            secretManagerId = schemas.StrSchema
            __annotations__ = {
                "script": script,
                "setup": setup,
                "setupStatus": setupStatus,
                "modelSetup": modelSetup,
                "secretManagerId": secretManagerId,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    script: MetaOapg.properties.script
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["script"]) -> MetaOapg.properties.script: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["setup"]) -> 'DatasetSetup': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["setupStatus"]) -> 'DatasetSetupStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["modelSetup"]) -> 'ModelSetup': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["secretManagerId"]) -> MetaOapg.properties.secretManagerId: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["script"], typing_extensions.Literal["setup"], typing_extensions.Literal["setupStatus"], typing_extensions.Literal["modelSetup"], typing_extensions.Literal["secretManagerId"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["script"]) -> MetaOapg.properties.script: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["setup"]) -> typing.Union['DatasetSetup', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["setupStatus"]) -> typing.Union['DatasetSetupStatus', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["modelSetup"]) -> typing.Union['ModelSetup', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["secretManagerId"]) -> typing.Union[MetaOapg.properties.secretManagerId, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["script"], typing_extensions.Literal["setup"], typing_extensions.Literal["setupStatus"], typing_extensions.Literal["modelSetup"], typing_extensions.Literal["secretManagerId"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        script: typing.Union[MetaOapg.properties.script, str, ],
        setup: typing.Union['DatasetSetup', schemas.Unset] = schemas.unset,
        setupStatus: typing.Union['DatasetSetupStatus', schemas.Unset] = schemas.unset,
        modelSetup: typing.Union['ModelSetup', schemas.Unset] = schemas.unset,
        secretManagerId: typing.Union[MetaOapg.properties.secretManagerId, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'DatasetMetadata':
        return super().__new__(
            cls,
            *args,
            script=script,
            setup=setup,
            setupStatus=setupStatus,
            modelSetup=modelSetup,
            secretManagerId=secretManagerId,
            _configuration=_configuration,
        )

from openapi_client.model.dataset_setup import DatasetSetup
from openapi_client.model.dataset_setup_status import DatasetSetupStatus
from openapi_client.model.model_setup import ModelSetup



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class ScatterVizDataState(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "metadata",
            "samples",
            "labels",
            "scatter_data",
        }
        
        class properties:
            
            
            class scatter_data(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    
                    class items(
                        schemas.ListSchema
                    ):
                    
                    
                        class MetaOapg:
                            items = schemas.Float64Schema
                    
                        def __new__(
                            cls,
                            arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, decimal.Decimal, int, float, ]], typing.List[typing.Union[MetaOapg.items, decimal.Decimal, int, float, ]]],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'items':
                            return super().__new__(
                                cls,
                                arg,
                                _configuration=_configuration,
                            )
                    
                        def __getitem__(self, i: int) -> MetaOapg.items:
                            return super().__getitem__(i)
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, list, tuple, ]], typing.List[typing.Union[MetaOapg.items, list, tuple, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'scatter_data':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class labels(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['ScatterLabel']:
                        return ScatterLabel
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['ScatterLabel'], typing.List['ScatterLabel']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'labels':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'ScatterLabel':
                    return super().__getitem__(i)
            
            
            class samples(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['SampleIdentity']:
                        return SampleIdentity
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['SampleIdentity'], typing.List['SampleIdentity']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'samples':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'SampleIdentity':
                    return super().__getitem__(i)
            metadata = schemas.DictSchema
        
            @staticmethod
            def data_state() -> typing.Type['DataStateType']:
                return DataStateType
            __annotations__ = {
                "scatter_data": scatter_data,
                "labels": labels,
                "samples": samples,
                "metadata": metadata,
                "data_state": data_state,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    metadata: MetaOapg.properties.metadata
    samples: MetaOapg.properties.samples
    labels: MetaOapg.properties.labels
    scatter_data: MetaOapg.properties.scatter_data
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["samples"]) -> MetaOapg.properties.samples: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["labels"]) -> MetaOapg.properties.labels: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["scatter_data"]) -> MetaOapg.properties.scatter_data: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data_state"]) -> 'DataStateType': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["metadata"], typing_extensions.Literal["samples"], typing_extensions.Literal["labels"], typing_extensions.Literal["scatter_data"], typing_extensions.Literal["data_state"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["samples"]) -> MetaOapg.properties.samples: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["labels"]) -> MetaOapg.properties.labels: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["scatter_data"]) -> MetaOapg.properties.scatter_data: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data_state"]) -> typing.Union['DataStateType', schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["metadata"], typing_extensions.Literal["samples"], typing_extensions.Literal["labels"], typing_extensions.Literal["scatter_data"], typing_extensions.Literal["data_state"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, ],
        samples: typing.Union[MetaOapg.properties.samples, list, tuple, ],
        labels: typing.Union[MetaOapg.properties.labels, list, tuple, ],
        scatter_data: typing.Union[MetaOapg.properties.scatter_data, list, tuple, ],
        data_state: typing.Union['DataStateType', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'ScatterVizDataState':
        return super().__new__(
            cls,
            *args,
            metadata=metadata,
            samples=samples,
            labels=labels,
            scatter_data=scatter_data,
            data_state=data_state,
            _configuration=_configuration,
        )

from openapi_client.model.data_state_type import DataStateType
from openapi_client.model.sample_identity import SampleIdentity
from openapi_client.model.scatter_label import ScatterLabel



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class Visualization(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "createdAt",
            "jobId",
            "data",
            "modelId",
            "visualizationUuid",
            "epoch",
            "_id",
            "type",
        }
        
        class properties:
            _id = schemas.StrSchema
            jobId = schemas.StrSchema
            modelId = schemas.StrSchema
        
            @staticmethod
            def type() -> typing.Type['AnalyzeTypeEnum']:
                return AnalyzeTypeEnum
            createdAt = schemas.DateTimeSchema
            epoch = schemas.Float64Schema
            visualizationUuid = schemas.StrSchema
        
            @staticmethod
            def data() -> typing.Type['VisualizationResponse']:
                return VisualizationResponse
        
            @staticmethod
            def jobParms() -> typing.Type['JobParams']:
                return JobParams
            sampleId = schemas.Float64Schema
        
            @staticmethod
            def layout() -> typing.Type['SizedLayout']:
                return SizedLayout
            __annotations__ = {
                "_id": _id,
                "jobId": jobId,
                "modelId": modelId,
                "type": type,
                "createdAt": createdAt,
                "epoch": epoch,
                "visualizationUuid": visualizationUuid,
                "data": data,
                "jobParms": jobParms,
                "sampleId": sampleId,
                "layout": layout,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    createdAt: MetaOapg.properties.createdAt
    jobId: MetaOapg.properties.jobId
    data: 'VisualizationResponse'
    modelId: MetaOapg.properties.modelId
    visualizationUuid: MetaOapg.properties.visualizationUuid
    epoch: MetaOapg.properties.epoch
    _id: MetaOapg.properties._id
    type: 'AnalyzeTypeEnum'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["jobId"]) -> MetaOapg.properties.jobId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> 'VisualizationResponse': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["modelId"]) -> MetaOapg.properties.modelId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["visualizationUuid"]) -> MetaOapg.properties.visualizationUuid: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["epoch"]) -> MetaOapg.properties.epoch: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> 'AnalyzeTypeEnum': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["jobParms"]) -> 'JobParams': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sampleId"]) -> MetaOapg.properties.sampleId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["layout"]) -> 'SizedLayout': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["jobId"], typing_extensions.Literal["data"], typing_extensions.Literal["modelId"], typing_extensions.Literal["visualizationUuid"], typing_extensions.Literal["epoch"], typing_extensions.Literal["_id"], typing_extensions.Literal["type"], typing_extensions.Literal["jobParms"], typing_extensions.Literal["sampleId"], typing_extensions.Literal["layout"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["jobId"]) -> MetaOapg.properties.jobId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> 'VisualizationResponse': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["modelId"]) -> MetaOapg.properties.modelId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["visualizationUuid"]) -> MetaOapg.properties.visualizationUuid: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["epoch"]) -> MetaOapg.properties.epoch: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> 'AnalyzeTypeEnum': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["jobParms"]) -> typing.Union['JobParams', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sampleId"]) -> typing.Union[MetaOapg.properties.sampleId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["layout"]) -> typing.Union['SizedLayout', schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["jobId"], typing_extensions.Literal["data"], typing_extensions.Literal["modelId"], typing_extensions.Literal["visualizationUuid"], typing_extensions.Literal["epoch"], typing_extensions.Literal["_id"], typing_extensions.Literal["type"], typing_extensions.Literal["jobParms"], typing_extensions.Literal["sampleId"], typing_extensions.Literal["layout"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        createdAt: typing.Union[MetaOapg.properties.createdAt, str, datetime, ],
        jobId: typing.Union[MetaOapg.properties.jobId, str, ],
        data: 'VisualizationResponse',
        modelId: typing.Union[MetaOapg.properties.modelId, str, ],
        visualizationUuid: typing.Union[MetaOapg.properties.visualizationUuid, str, ],
        epoch: typing.Union[MetaOapg.properties.epoch, decimal.Decimal, int, float, ],
        _id: typing.Union[MetaOapg.properties._id, str, ],
        type: 'AnalyzeTypeEnum',
        jobParms: typing.Union['JobParams', schemas.Unset] = schemas.unset,
        sampleId: typing.Union[MetaOapg.properties.sampleId, decimal.Decimal, int, float, schemas.Unset] = schemas.unset,
        layout: typing.Union['SizedLayout', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Visualization':
        return super().__new__(
            cls,
            *args,
            createdAt=createdAt,
            jobId=jobId,
            data=data,
            modelId=modelId,
            visualizationUuid=visualizationUuid,
            epoch=epoch,
            _id=_id,
            type=type,
            jobParms=jobParms,
            sampleId=sampleId,
            layout=layout,
            _configuration=_configuration,
        )

from openapi_client.model.analyze_type_enum import AnalyzeTypeEnum
from openapi_client.model.job_params import JobParams
from openapi_client.model.sized_layout import SizedLayout
from openapi_client.model.visualization_response import VisualizationResponse
